@@ -491,17 +491,17 @@ cd_main_get_seat_for_process (guint pid)
 
 	/* get session the process belongs to */
 	rc = sd_pid_get_session (pid, &sd_session);
-	if (rc != 0) {
-		g_warning ("failed to get session [pid %u]: %s",
-			   pid, strerror (-rc));
+	if (rc < 0) {
+		g_debug ("failed to get session [pid %u]: %s",
+			 pid, strerror (-rc));
 		goto out;
 	}
 
 	/* get the seat the session is on */
 	rc = sd_session_get_seat (sd_session, &sd_seat);
-	if (rc != 0) {
-		g_warning ("failed to get seat for session %s [pid %u]: %s",
-			   sd_session, pid, strerror (-rc));
+	if (rc < 0) {
+		g_debug ("failed to get seat for session %s [pid %u]: %s",
+			 sd_session, pid, strerror (-rc));
 		goto out;
 	}
 	seat = g_strdup (sd_seat);
@@ -796,12 +796,12 @@ cd_main_get_cmdline_for_pid (guint pid)
 	proc_path = g_strdup_printf ("/proc/%u/cmdline", pid);
 	ret = g_file_get_contents (proc_path, &cmdline, &len, &error);
 	if (!ret) {
-		g_warning ("CdMain: failed to read %s: %s",
+		g_debug ("CdMain: failed to read %s: %s",
 			   proc_path, error->message);
 		return NULL;
 	}
 	if (len == 0) {
-		g_warning ("CdMain: failed to read %s", proc_path);
+		g_debug ("CdMain: failed to read %s", proc_path);
 		g_free (cmdline);
 		return NULL;
 	}
