@@ -26,7 +26,6 @@
 #include <colord-private.h>
 
 #include "cd-device.h"
-#include "cd-config.h"
 
 G_BEGIN_DECLS
 
@@ -38,7 +37,7 @@ typedef void		 (*CdPluginFunc)		(CdPlugin	*plugin);
 typedef void		 (*CdPluginDeviceFunc)		(CdPlugin	*plugin,
 							 CdDevice	*device,
 							 gpointer	 user_data);
-typedef gboolean	 (*CdPluginConfigEnabledFunc)	(CdConfig	*config);
+typedef gboolean	 (*CdPluginEnabledFunc)	(void);
 
 struct CdPlugin {
 	GModule			*module;
@@ -70,7 +69,7 @@ void		 cd_plugin_device_removed		(CdPlugin	*plugin,
 							 CdDevice	*device);
 
 /* optional function which returns false if plugin should not be enabled */
-gboolean	 cd_plugin_config_enabled		(CdConfig	*config);
+gboolean	 cd_plugin_config_enabled		(void);
 
 G_END_DECLS
 
